.TH  "TCLPARSE" N
.SH NAME
tclparse \- parse a tcl script for syntactical errors

.SH SYNOPSIS
\fBtclparse\fP \fIfile1.tcl\fP ?\fIoptions\fP?

.SH OPTIONS
If the \fB-commands\fP (shortcut \fB-c\fP) option is given,
\fItclparse\fP will print the name of a tcl or tk command each time
one is encountered.

The \fB-infofile <ini-file> \fP (shortcut \fB-i\fP) option needs one
argument which is the name of an alternative \fIinformation file\fP,
such as build with \fItclmerge\fP. \fItclparse\fP will use this file
instead of the standard file generated with \fItclscan\fP.

If the \fB-nocode\fP (shortcut \fB-nc\fP) option is given,
\fItclparse\fP will not print lines of the program code with an error
message.

If the \fB-noerrors\fP (shortcut \fB-ne\fP) option is given,
\fItclparse\fP will not print error messages.

If the \fB-nowarnings\fP (shortcut \fB-nw\fP) option is given,
\fItclparse\fP will not print warning messages.

If the \fB-procedures\fP (shortcut \fB-p\fP) option is given,
\fItclparse\fP will print the name of a procedure each time a
\fIproc\fP command is encountered.

If the \fB-tcl\fP option is given, \fItclparse\fP will only work with
tcl commands. If this option is not given, \fItclparse\fP will work
with all tcl commands and all tk commands.

If the \fB-variables\fP (shortcut \fB-v\fP) option is given,
\fItclparse\fP will print the name of a variable each time the
variable is used.

If the \fB-widgets\fP (shortcut \fB-w\fP) option is given,
\fItclparse\fP will print the name of a tk widget each time a known
widget is encountered.

.SH DESCRIPTION
The \fItclparse\fP program is used to parse a tcl script for
syntactical errors. To do this, the data from the corresponding
\fIinformation file\fP is used.

If this \fIinformation file\fP does not exist because it was not
created with \fItclscan\fP or \fItclmerge\fP, the program will run
without knowing the new commands and global variables. This normally
results in an orgy of error messages.

The main thing \fItclparse\fP does is to read a command and it's
arguments and check if the correct number of arguments was given.
For commands like \fIif\fP, \fIproc\fP or \fIwhile\fP that use command
bodies, these bodies are not only read but also parsed for errors. 

.SH SPECIAL INFORMATION
To check the options many commands allow, \fItclparse\fP
needs the file \fI.options.tclparse\fP. If not available, this file
can be built by running '\fBwish options.tcl\fP' in the ./init
subdirectory. The file \fI.options.tclparse\fP contains
the valid options and switches for most of the tcl commands.

The file \fI.vars.tclparse\fP contains the names of all (?) Tcl and Tk
system variables. Although there (should) exists a standard \fI.vars.tclparse\fP file , the file should be rebuild because some variable
names depend on environment variables of the system. To adapt the file
to your system, in the ./init subdirectory run '\fBwish
vars.tcl\fP'.

Both files, \fI.options.tclparse\fP and \fI.vars.tclparse\fP are
expected to be in the home directory.

.SH BIND
The \fItag\fP argument that is required for the tk \fIbind\fP command
is not checked for errors but only read in. Same for the optional
\fIsequence\fP argument, only that if the first character is the '<'
symbol (or '<<') a check for the corresponding '>' symbol (or '>>') is
performed. In the \fIscript\fP argument tk allows you to specify
substitutions starting with the '%' symbol. Since these substitutions
are performed by tk \fBat runtime\fP, \fItclparse\fP can not evaluate
these substitutions. If such a substitution is used as a command (like
\fB%W\fP) the program will print an "unknown command" error message.

.SH CANVAS
With the tk \fIcanvas create\fP command different canvas items like
arcs, lines and windows may be created. These items get an id \fBat
runtime\fP.
With the commands \fIcanvas itemcget\fP or \fIcanvas itemconfigure\fP
you may get specific information about these items. Depending on the
used item the command has different options. Since the id does not
exist when parsing the tcl script, \fItclparse\fP can not identify the
type of the item. The behaviour of \fItclparse\fP in this case is to
accept an option if it is valid for any canvas item.

.SH CASE
The \fIcase\fP command is not supported in this version and perhaps
never will be, because in the corresponding manual page there is a
note that says: THE CASE COMMAND IS OBSOLETE...

.SH IF
The test expressions which are required after \fIif\fP and
\fIelseif\fP are just read in and not checked for errors. Included
commands are not parsed.

.SH INTERP 
With the tcl \fIinterp\fP command separate interpreters may be
created. If the name for the new interpreter is omitted, tcl will
create a standard name \fBat runtime\fP.  This is one reason why
\fItclparse\fP will not recognize \fBany\fP names of interpreters as
tcl commands.  Let's see what the future will bring.

.SH PACK
For the tk \fIpack\fP command, there exists an obsolete
syntax. \fItclparse\fP supports the old and new syntax for this
command. In the old form there are the \fIpack after\fP, \fIpack
append\fP and \fIpack before\fP commands which allow to specify
several options. These option lists are just read in and not checked
for errors.

.SH PROCEDURE ARGUMENTS
\fItclparse\fP accepts the \fIargs\fP argument, that is, it allows
zero or infinite arguments from the point where \fIargs\fP is
encountered in an argument list.
Argument lists in quotes are not yet supported.

.SH RENAME
When parsing the tcl \fIrename\fP command, \fItclparse\fP does (not
now) rename the command in it's internal command environment. Using
the new command name will generate error messages. Sorry.

.SH ADDING NEW COMMANDS TO THE PROGRAM
Each time a tcl command is encountered, a procedure named
\fBParseTcl...Cmd\fP is called to parse that command - for tk commands
that is \fBParseTk...Cmd\fP.
If new commands should be added to the program, for example
self-written commands in C, it is necessary to add such a procedure to
the program. The procedures for parsing tcl commands are in the file
\fIsource/tclcmd.cc\fP, those for tk commands are in
\fIsource/tkcmd.cc\fP. Also the corresponding header file in the
\fIinclude\fP directory should be changed.

A look at some of the existing procedures should help to understand
how to build an own procedure.

To identify tcl/tk commands, \fItclparse\fP uses the strings
\fBtclCommandList\fP and \fBtkCommandList\fP in the file
\fIinclude/const.h\fP. The name of the command must be added to the
corresponding list.

The two procedures \fBParseTclCommand\fP and \fBParseTkCommand\fP in
the file \fIsource/parsing.cc\fP call the specific procedures for
parsing a tcl/tk command. A new branch for the new command must be
added in the corresponding procedure.


.SH BUGS AND LIMITATIONS
\fItclparse\fP was written with the GNU project C++ Compiler on an
intel-based linux-pc. Therefore we don't know how the program will
react in other environments.

.SH AUTHORS
Stephan Weiss & Heiko Grossman

Homepage: http://www.informatik.uni-stuttgart.de/ipvr/swlab/sopra/tclsyntax/tclparseHome.html

.SH VERSION 
V2.00 from 14. March 1997 

This program is distributed in the hope that it will be useful, but
\fBWITHOUT ANY WARRANTY\fP; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

.SH RELATED COMMANDS
\fItclparse\fP is part of a package which contains also
the programs \fItclmerge\fP and \fItclscan\fP. See the corresponding
manual pages for details.